﻿using System.ComponentModel;
using System.Windows;
using Telerik.Windows.Controls.Charting;

namespace SilverlightApplication1
{
    public class CustomScatterPoint : ScatterPoint
    {
        /// <summary>
        /// Identifies the <see cref="CanvasLeft"/> dependency property.
        /// </summary>
        public static readonly DependencyProperty CanvasLeftProperty = DependencyProperty.Register("CanvasLeft",
            typeof(double),
            typeof(CustomScatterPoint),
            new PropertyMetadata(null));


        /// <summary>
        /// Identifies the <see cref="CanvasTop"/> dependency property.
        /// </summary>
        public static readonly DependencyProperty CanvasTopProperty = DependencyProperty.Register("CanvasTop",
            typeof(double),
            typeof(CustomScatterPoint),
            new PropertyMetadata(null));

        /// <summary>
        /// Gets or sets the CanvasTop.
        /// </summary>
        [Description("Gets or sets the CanvasTop")]
        public double CanvasTop
        {
            get
            {
                return (double)this.GetValue(CanvasTopProperty);
            }
            set
            {
                this.SetValue(CanvasTopProperty, value);
            }
        }

        /// <summary>
        /// Gets or sets the CanvasLeft.
        /// </summary>
        [Description("Gets or sets the CanvasLeft")]
        public double CanvasLeft
        {
            get
            {
                return (double)this.GetValue(CanvasLeftProperty);
            }
            set
            {
                this.SetValue(CanvasLeftProperty, value);
            }
        }

        public CustomScatterPoint()
        {
            this.SizeChanged += new SizeChangedEventHandler(CustomScatterPoint_SizeChanged);
        }

        void CustomScatterPoint_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            this.CanvasLeft = -this.PointSize / 2;
            this.CanvasTop = this.StartPointY - this.PointSize / 2;
        }
    }
}
